@@ -8,14 +8,21 @@ mod location;
 pub trait Demon: std::marker::Send {
     type Input;
     type Output;
-    /// Handler function for messages
-    async fn handle(&mut self, message: Self::Input) -> Self::Output;
     /// Callback, for when the demon is spawned
     async fn spawned(&mut self, _location: Location<Self>) {
         ()
     }
+    /// Handler function for messages
+    async fn handle(&mut self, message: Self::Input) -> Self::Output;
     /// Callback, for when the demon is dismissed
     async fn vanquished(&mut self) {
         ()
     }
+    /// This id will be printed in the debug logs of the demon's thread.
+    ///
+    /// It is useful when some lockup is happening and you have trouble to find it.
+    #[cfg(feature = "internal_log")]
+    fn id(&self) -> &str {
+        ""
+    }
 }
\ No newline at end of file
